# Application Configuration
app:
  name: {{ config.project.name }}
  version: {{ config.project.version }}
  environment: {{ config.project.environment | default('development') }}

service_name: {{ config.project.name | camel_case }}
service_version: {{ config.project.version }}
environment: {{ config.project.environment | default('Dev') }}
