"""
Pydantic models for {{ config.project.name }}
"""

{% for endpoint in endpoints %}
{% if endpoint.params %}
from .{{ endpoint.name }} import {{ endpoint.name | camel_case }}Request, {{ endpoint.name | camel_case }}Response
{% endif %}
{% endfor %}

__all__ = [
{% for endpoint in endpoints %}
{% if endpoint.params %}
    "{{ endpoint.name | camel_case }}Request",
    "{{ endpoint.name | camel_case }}Response",
{% endif %}
{% endfor %}
]